@@ -25,19 +25,19 @@ class DetectController:
         raise Exception(res.text)
 
     @verify_credentials
-    def enable_test(self, ident, run_code):
-        """ Activate a test so endpoints will start running it """
+    def enable_test(self, ident: str, run_code: int, tags: list):
+        """ Enable a test so endpoints will start running it """
         res = requests.post(
             url=f'{self.account.hq}/account/queue/{ident}',
             headers=self.account.headers,
-            json=dict(run_code=run_code)
+            json=dict(code=run_code, tags=tags)
         )
         if res.status_code != 200:
             raise Exception(res.text)
 
     @verify_credentials
     def disable_test(self, ident):
-        """ Deactivate a test so endpoints will stop running it """
+        """ Disable a test so endpoints will stop running it """
         res = requests.delete(f'{self.account.hq}/account/queue/{ident}', headers=self.account.headers)
         if res.status_code != 200:
             raise Exception(res.text)
@@ -60,3 +60,11 @@ class DetectController:
         if res.status_code == 200:
             return res.url
         raise Exception(res.text)
+
+    @verify_credentials
+    def list_tags(self):
+        """ Get all tags associated to an Account """
+        res = requests.get(f'{self.account.hq}/account/tag', headers=self.account.headers)
+        if res.status_code == 200:
+            return res.json()
+        raise Exception(res.text)
